..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

======
runops
======

.. automodule:: textops.ops.runops
.. currentmodule:: textops

mrun
----
   .. autoclass:: mrun(context={})

run
---
   .. autoclass:: run(context={})

xrun
----
   .. autoclass:: xrun(cmd, context={}, defvalue='unknwon')
